stsynphot
=========

.. image:: https://readthedocs.org/projects/stsynphot/badge/?version=latest
    :target: http://stsynphot.readthedocs.io/en/latest/?badge=latest
    :alt: Documentation Status

.. image:: https://travis-ci.org/spacetelescope/stsynphot_refactor.svg?branch=master
    :target: https://travis-ci.org/spacetelescope/stsynphot_refactor

.. image:: https://ci.appveyor.com/api/projects/status/h6e7fycv3jww0d94/branch/master?svg=true
    :target: https://ci.appveyor.com/project/pllim/stsynphot-refactor/branch/master

.. image:: https://coveralls.io/repos/github/spacetelescope/stsynphot_refactor/badge.svg?branch=master
    :target: https://coveralls.io/github/spacetelescope/stsynphot_refactor?branch=master

This is a replacement for IRAF STSDAS SYNPHOT and ASTROLIB PYSYNPHOT, utilizing Astropy
covering instrument specific portions of the old packages for HST (and soon JWST).
